@@ -11,7 +11,7 @@ from {{cookiecutter.project_name}}.settings import settings
 
 # this is the Alembic Config object, which provides
 # access to the values within the .ini file in use.
-config = context.config
+config = context.config  # type: ignore
 
 
 load_all_models()
